##  Legacy Configuration
**Note**
Legacy Software Management Connection
If in case legacy software management module is in use instead of SAM/SAM Pro and Discovery Service, the Integration can be adapted instead to follow the following flow chart instead -
![1788](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746d0f57a441014982cb90e1cbcabb0_LowRes.png)
Legacy workflow
